@@ -35,7 +35,11 @@ def _scan_dir(start_path: str, extension: str = None) -> Iterator[str]:
 
 
 def upload(
-    start_dir: str, endpoint: str = None, api_key: str = None, verbose: bool = False
+    start_dir: str,
+    project_id: int,
+    endpoint: str = None,
+    api_key: str = None,
+    verbose: bool = False,
 ):
     if api_key is None:
         api_key = os.getenv("JAMA_API_KEY", None)
